@@ -5,7 +5,9 @@
     utils::globalVariables(
       c("value", "variable", "word_count", "w",
         "attrib", "feature", "id", "i", "wLex",
-        "wFeat", "wTime", "x", "identifier", "lag")
+        "wFeat", "wTime", "x", "identifier",
+        ".", "documents", "language", "nTokens",
+        "lag", "sentence_id", "count")
     )
   invisible()
 }
