@@ -16,7 +16,8 @@ Rcpp::NumericMatrix compute_sentiment_valence(std::vector< std::vector<std::stri
                                               std::string how) {
 
   int nTexts = texts.size(); // already tokenized texts
-  int nL = lexicons.size() - 1;
+  int nL = lexicons.size() - 1; // the last one is the valence shifter
+  bool isFreqWeighting = is_frequency_weighting(how);
   Rcpp::CharacterVector colNames = prepare_column_names(lexicons.names(), nL);
 
   std::unordered_map< std::string, std::vector<double> > lexiconMap = make_lexicon_map(lexicons, nL);
@@ -24,13 +25,18 @@ Rcpp::NumericMatrix compute_sentiment_valence(std::vector< std::vector<std::stri
   Rcpp::List valenceList = lexicons[nL];
   Rcpp::CharacterVector valenceCols = valenceList.names();
   std::unordered_map< std::string, double > valenceMap = make_valence_map(valenceList);
+  std::unordered_map< int, std::unordered_map<std::string, double> > frequencyMap;
+  std::unordered_map< std::string, double > inverseFrequencyMap;
+  if (isFreqWeighting) {
+    make_frequency_maps(frequencyMap, inverseFrequencyMap, texts);
+  }
 
   Rcpp::NumericMatrix sentScores(nTexts, nL + 1); // output matrix of word count and sentiment scores
   if (valenceCols[1] == "y") {
-    SentimentScorerBigrams sentimentScorer(texts, lexiconMap, valenceMap, how, nL, sentScores);
+    SentimentScorerBigrams sentimentScorer(texts, lexiconMap, valenceMap, how, nL, frequencyMap, inverseFrequencyMap, isFreqWeighting, sentScores);
     parallelFor(0, nTexts, sentimentScorer);
   } else if (valenceCols[1] == "t") {
-    SentimentScorerClusters sentimentScorer(texts, lexiconMap, valenceMap, how, nL, sentScores);
+    SentimentScorerClusters sentimentScorer(texts, lexiconMap, valenceMap, how, nL, frequencyMap, inverseFrequencyMap, isFreqWeighting, sentScores);
     parallelFor(0, nTexts, sentimentScorer);
   }
 
