@@ -18,10 +18,10 @@ lex <- sento_lexicons(list_lexicons[c("GI_en", "LM_en")])
 ctrA <- ctr_agg(howWithin = "counts", howDocs = "proportional", howTime = "almon", by = "day",
                 lag = 24, ordersAlm = 1:3, do.inverseAlm = TRUE, do.ignoreZeros = FALSE, fill = "latest")
 
-sentomeasures <- sento_measures(corpus, lex, ctrA)
+sento_measures <- sento_measures(corpus, lex, ctrA)
 
 # preparation of estimation data
-N <- nobs(sentomeasures)
+N <- nobs(sento_measures)
 y <- rnorm(N) # random y variable
 x <- data.frame(runif(N), rnorm(N)) # two additional random x variables
 colnames(x) <- c("x1", "x2")
@@ -29,11 +29,11 @@ colnames(x) <- c("x1", "x2")
 # model run
 ctrM <- ctr_model(model = "gaussian", type = "Cp", do.iter = TRUE, h = 3, lambdas = NULL,
                   nSample = N - 12, do.shrinkage.x = TRUE, alphas = 0)
-out <- sento_model(sentomeasures, y, x = x, ctr = ctrM)
+out <- sento_model(sento_measures, y, x = x, ctr = ctrM)
 
 ### tests from here ###
 
-attributions <- attributions(out, sentomeasures, do.normalize = FALSE)
+attributions <- attributions(out, sento_measures, do.normalize = FALSE)
 
 l <- rowSums(attributions$lexicons[, -1], na.rm = TRUE)
 f <- rowSums(attributions$features[, -1], na.rm = TRUE)
